#[repr(i32)]pub enum EdgeDirection {
Outbound = 0,
Inbound = 1,
}Expand description
Specifies what kind of items should be piped from one type of query to another.
Edge and vertex queries can build off of one another via pipes - e.g. you
can get the outbound edges of a set of vertices by piping from a vertex
query to an edge query. EdgeDirections are used to specify which
end of things you want to pipe - either the outbound items or the inbound
items.
Variants
Implementations
Sourceimpl EdgeDirection
impl EdgeDirection
Sourceimpl EdgeDirection
impl EdgeDirection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.