pub struct PipeWithPropertyPresenceQuery {
pub inner: Option<Box<Query>>,
pub name: Option<Identifier>,
pub exists: bool,
}Expand description
Gets vertices or edges with or without a property.
Fields
inner: Option<Box<Query>>The query to filter.
name: Option<Identifier>The name of the property.
exists: boolWhether we should look for property presence or lack thereof.